@@ -27,6 +27,29 @@ plot.iris <- ggplot(iris, aes(Sepal.Length, Sepal.Width)) +
 plot_grid(plot.iris, plot.mpg, labels = "AUTO", ncol = 1, 
           align = 'v') # aligning does not work here
 
+## ---- message=FALSE, fig.width=4.25, fig.height=5.1----------------------
+require(grid) # for unit.pmax(), unit.list()
+g.iris <- ggplotGrob(plot.iris) # convert to gtable
+g.mpg <- ggplotGrob(plot.mpg) # convert to gtable
+
+if(getRversion() < "3.3.0"){
+  # We need to convert the widths to unit lists for the subsequent
+  # manipulations to be possible.
+  # Once R 3.3.0 is released, this will not be necessary anymore.
+  g.iris$widths <- grid:::unit.list(g.iris$widths)   
+  g.mpg$widths <-  grid:::unit.list(g.mpg$widths)
+}
+
+iris.widths <- g.iris$widths[1:3] # extract the first three widths, 
+                                  # corresponding to left margin, y lab, and y axis
+mpg.widths <- g.mpg$widths[1:3] # same for mpg plot
+max.widths <- unit.pmax(iris.widths, mpg.widths) # calculate maximum widths
+g.iris$widths[1:3] <- max.widths # assign max widths to iris gtable
+g.mpg$widths[1:3] <- max.widths # assign max widths to mpg gtable
+
+# plot_grid() can work directly with gtables, so this works
+plot_grid(g.iris, g.mpg, labels = "AUTO", ncol = 1)
+
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
 plot_grid(plot.mpg, plot.diamonds, labels = "AUTO", align = 'h', label_size = 12)
 
